@@ -1,5 +1,5 @@
 """
-Dwarf - Copyright (C) 2019 Giovanni Rocca (iGio90)
+    Dwarf - Copyright (C) 2018-2020 Giovanni Rocca (iGio90)
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -433,8 +433,8 @@ class Adb(QObject):
         else:
             return None
 
-        result = result.replace('\r', '').replace('\n', '')
-        check_ver = result.split('.')
+        result = result.split(os.linesep)
+        check_ver = result[len(result) - 2].replace('\r', '').split('.')
         if len(check_ver) == 3:
             try:
                 v_major = int(check_ver[0])
