@@ -1,13 +1,16 @@
 """
-Dwarf - Copyright (C) 2019 Giovanni Rocca (iGio90)
+    Dwarf - Copyright (C) 2018-2020 Giovanni Rocca (iGio90)
+
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
+
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
+
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <https://www.gnu.org/licenses/>
 """
@@ -101,10 +104,10 @@ class JavaTraceView(QtWidgets.QAbstractScrollArea):
         for i, line in enumerate(self.data):
             if i == self.pos:
                 break
-            if line['event'] == 'leave':
+            """if line['event'] == 'leave':
                 trace_depth -= 1
             elif line['event'] == 'enter':
-                trace_depth += 1
+                trace_depth += 1"""
 
         for i, line in enumerate(self.data[data_start:data_end]):
             if i > self.visible_lines():
@@ -119,9 +122,9 @@ class JavaTraceView(QtWidgets.QAbstractScrollArea):
             painter.setPen(QtGui.QColor('#fff'))
 
             if line['event'] == 'leave':
-                if trace_depth:
-                    trace_depth -= 1
-                drawing_pos_x += (trace_depth * 20)
+                """if trace_depth:
+                    trace_depth -= 1"""
+                drawing_pos_x += (1 * 20)
                 painter.setPen(QtGui.QColor('crimson'))
                 painter.setBrush(QtGui.QColor('#222'))
                 polygon = QtGui.QPolygon()
@@ -139,8 +142,8 @@ class JavaTraceView(QtWidgets.QAbstractScrollArea):
                     QtCore.QPoint(drawing_pos_x - 6, drawing_pos_y + (self._char_height * 0.5)))
                 painter.drawPolygon(polygon)
             elif line['event'] == 'enter':
-                trace_depth += 1
-                drawing_pos_x += (trace_depth * 20)
+                #trace_depth += 1
+                drawing_pos_x += (1 * 20)
                 painter.setPen(QtGui.QColor('yellowgreen'))
                 painter.setBrush(QtGui.QColor('#222'))
                 polygon = QtGui.QPolygon()
@@ -168,7 +171,7 @@ class JavaTraceView(QtWidgets.QAbstractScrollArea):
                 for a in range(len(line['data'])):
                     arg_str += 'arg_{0}, '.format(a)
 
-                if len(line['data']):
+                if line['data']:
                     arg_str = arg_str[:-2]
                 arg_str += ')'
                 painter.drawText(
